/*
 * Client test program for apcnetd
 * This program reads from standard input and passes the
 * commands to the apcupsd network information server.
 * It then prints to stdout the responses from the server.
 *
 * Build it with: cc client.c ../apcnetlib.c -o client
 *
 * Execute: ./client <host-name or IP-address>
 *   reads commands from STDIN
 *
 * The two commands currently (Jan 2000) accepted by the
 * server are "status" and "events".
 *
 * For additional examples of code, see cgi/upsfetch.c
 */

#include <stdio.h>
#include <sys/types.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <arpa/inet.h>
#include <netdb.h>

#define SERV_TCP_PORT 7000
#define SERV_HOST_ADDR "127.0.0.1"

void handle_client();

extern int net_errno;

struct sockaddr_in tcp_serv_addr;

void error_abort(char *msg)
{
   fprintf(stderr, msg);
   exit(1);
}

int main(int argc, char *argv[]) 
{
   int sockfd;
   char host[200];
   char msg[200];

   strcpy(host, SERV_HOST_ADDR);
       
   if (argc > 1)
      strcpy(host, argv[1]); /* get host from command line */

   if ((sockfd = net_open(host, NULL, SERV_TCP_PORT)) < 0) {
      sprintf(msg, "client: tcp_open for host %s failed\n", host);
      error_abort(msg);
   }

   handle_client(stdin, sockfd);	    /* do it all */
   net_close(sockfd);
   exit(0);
}   

/*
 * Read the contents of the FILE *fp, write each line to the 
 * stream socket (to the server process), then read a line back from	 
 * the socket and write it to the standard output.
 *
 * Return to the caller when an EOF is encountered on the input file.
 */

#define MAXLINE 5000

void handle_client(FILE *fp, int sockfd)
{
   int n; 
   long nlines;
   char sendline[MAXLINE];
   char recvline[MAXLINE+1];

   while (fgets(sendline, MAXLINE, fp) != NULL) {
      n = strlen(sendline);
      if (net_send(sockfd, sendline, n) != n)
         error_abort("handle_client: writen error on socket");

      while ((n = net_recv(sockfd, recvline, sizeof(recvline))) > 0) {
	  recvline[n] = 0;
	  fputs(recvline, stdout);
      }
      if (n < 0) {
	 char msg[200];
         sprintf(msg, "handle_client: net_recv error: %s\n", strerror(net_errno));
	 error_abort(msg);
     }
   }
}
